@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -39,28 +34,28 @@
 #include "qdesigner_objectinspector_p.h"
 #include "promotiontaskmenu_p.h"
 
-#include <QtDesigner/QDesignerFormWindowInterface>
-#include <QtDesigner/QDesignerPropertyEditorInterface>
-#include <QtDesigner/QDesignerFormEditorInterface>
+#include <QtDesigner/abstractformwindow.h>
+#include <QtDesigner/abstractpropertyeditor.h>
+#include <QtDesigner/abstractformeditor.h>
 #include <actionprovider_p.h>
-#include <QtDesigner/QExtensionManager>
-#include <QtDesigner/QDesignerWidgetFactoryInterface>
+#include <QtDesigner/qextensionmanager.h>
+#include <QtDesigner/abstractwidgetfactory.h>
 
-#include <QtWidgets/QAction>
-#include <QtWidgets/QApplication>
-#include <QtWidgets/QToolButton>
-#include <QtWidgets/QToolBar>
-#include <QtWidgets/QMenu>
+#include <QtWidgets/qaction.h>
+#include <QtWidgets/qapplication.h>
+#include <QtWidgets/qtoolbutton.h>
+#include <QtWidgets/qtoolbar.h>
+#include <QtWidgets/qmenu.h>
 #include <QtGui/qevent.h>
-#include <QtGui/QDrag>
-#include <QtWidgets/QApplication>
-#include <QtCore/QDebug>
+#include <QtGui/qdrag.h>
+#include <QtWidgets/qapplication.h>
+#include <QtCore/qdebug.h>
 
 Q_DECLARE_METATYPE(QAction*)
 
 QT_BEGIN_NAMESPACE
 
-typedef QList<QAction*> ActionList;
+using ActionList = QList<QAction *>;
 
 namespace qdesigner_internal {
 // ------------------- ToolBarEventFilter
@@ -74,22 +69,19 @@ void ToolBarEventFilter::install(QToolBar *tb)
 ToolBarEventFilter::ToolBarEventFilter(QToolBar *tb) :
     QObject(tb),
     m_toolBar(tb),
-    m_promotionTaskMenu(0)
+    m_promotionTaskMenu(nullptr)
 {
 }
 
 ToolBarEventFilter *ToolBarEventFilter::eventFilterOf(const QToolBar *tb)
 {
     // Look for 1st order children only..otherwise, we might get filters of nested widgets
-    const QObjectList children = tb->children();
-    const QObjectList::const_iterator cend = children.constEnd();
-    for (QObjectList::const_iterator it = children.constBegin(); it != cend; ++it) {
-        QObject *o = *it;
+    for (QObject *o : tb->children()) {
         if (!o->isWidgetType())
             if (ToolBarEventFilter *ef = qobject_cast<ToolBarEventFilter *>(o))
                 return ef;
     }
-    return 0;
+    return nullptr;
 }
 
 bool ToolBarEventFilter::eventFilter (QObject *watched, QEvent *event)
@@ -132,13 +124,13 @@ ActionList ToolBarEventFilter::contextMenuActions(const QPoint &globalPos)
 {
     ActionList rc;
     const int index = actionIndexAt(m_toolBar, m_toolBar->mapFromGlobal(globalPos), m_toolBar->orientation());
-    const ActionList actions = m_toolBar->actions();
+    const auto actions = m_toolBar->actions();
     QAction *action = index != -1 ?actions.at(index) : 0;
     QVariant itemData;
 
     // Insert before
     if (action && index != 0 && !action->isSeparator()) {
-        QAction *newSeperatorAct = new QAction(tr("Insert Separator before '%1'").arg(action->objectName()), 0);
+        QAction *newSeperatorAct = new QAction(tr("Insert Separator before '%1'").arg(action->objectName()), nullptr);
         itemData.setValue(action);
         newSeperatorAct->setData(itemData);
         connect(newSeperatorAct, &QAction::triggered, this, &ToolBarEventFilter::slotInsertSeparator);
@@ -146,9 +138,9 @@ ActionList ToolBarEventFilter::contextMenuActions(const QPoint &globalPos)
     }
 
     // Append separator
-    if (actions.empty() || !actions.back()->isSeparator()) {
-        QAction *newSeperatorAct = new QAction(tr("Append Separator"), 0);
-        itemData.setValue(static_cast<QAction*>(0));
+    if (actions.isEmpty() || !actions.constLast()->isSeparator()) {
+        QAction *newSeperatorAct = new QAction(tr("Append Separator"), nullptr);
+        itemData.setValue(static_cast<QAction*>(nullptr));
         newSeperatorAct->setData(itemData);
         connect(newSeperatorAct, &QAction::triggered, this, &ToolBarEventFilter::slotInsertSeparator);
         rc.push_back(newSeperatorAct);
@@ -159,14 +151,14 @@ ActionList ToolBarEventFilter::contextMenuActions(const QPoint &globalPos)
     m_promotionTaskMenu->addActions(formWindow(), PromotionTaskMenu::LeadingSeparator|PromotionTaskMenu::TrailingSeparator, rc);
     // Remove
     if (action) {
-        QAction *a = new QAction(tr("Remove action '%1'").arg(action->objectName()), 0);
+        QAction *a = new QAction(tr("Remove action '%1'").arg(action->objectName()), nullptr);
         itemData.setValue(action);
         a->setData(itemData);
         connect(a, &QAction::triggered, this, &ToolBarEventFilter::slotRemoveSelectedAction);
         rc.push_back(a);
     }
 
-    QAction *remove_toolbar = new QAction(tr("Remove Toolbar '%1'").arg(m_toolBar->objectName()), 0);
+    QAction *remove_toolbar = new QAction(tr("Remove Toolbar '%1'").arg(m_toolBar->objectName()), nullptr);
     connect(remove_toolbar, &QAction::triggered, this, &ToolBarEventFilter::slotRemoveToolBar);
     rc.push_back(remove_toolbar);
     return rc;
@@ -179,7 +171,7 @@ bool ToolBarEventFilter::handleContextMenuEvent(QContextMenuEvent * event )
     const QPoint globalPos = event->globalPos();
     const ActionList al = contextMenuActions(event->globalPos());
 
-    QMenu menu(0);
+    QMenu menu(nullptr);
     const ActionList::const_iterator acend = al.constEnd();
     for (ActionList::const_iterator it = al.constBegin(); it != acend; ++it)
         menu.addAction(*it);
@@ -194,14 +186,14 @@ void ToolBarEventFilter::slotRemoveSelectedAction()
         return;
 
     QAction *a = qvariant_cast<QAction*>(action->data());
-    Q_ASSERT(a != 0);
+    Q_ASSERT(a != nullptr);
 
     QDesignerFormWindowInterface *fw = formWindow();
     Q_ASSERT(fw);
 
     const ActionList actions = m_toolBar->actions();
     const int pos = actions.indexOf(a);
-    QAction *action_before = 0;
+    QAction *action_before = nullptr;
     if (pos != -1 && actions.count() > pos + 1)
         action_before = actions.at(pos + 1);
 
@@ -366,7 +358,7 @@ bool ToolBarEventFilter::handleDropEvent(QDropEvent *event)
     }
 
     // Try to find action to 'insert before'. Click on action or in free area, else ignore.
-    QAction *beforeAction = 0;
+    QAction *beforeAction = nullptr;
     const QPoint pos = event->pos();
     const int index = actionIndexAt(m_toolBar, pos, m_toolBar->orientation());
     if (index != -1) {
@@ -411,11 +403,11 @@ void ToolBarEventFilter::startDrag(const QPoint &pos, Qt::KeyboardModifiers modi
     drag->setPixmap(ActionRepositoryMimeData::actionDragPixmap( action));
     drag->setMimeData(new ActionRepositoryMimeData(action, dropAction));
 
-    if (drag->start(dropAction) == Qt::IgnoreAction) {
+    if (drag->exec(dropAction) == Qt::IgnoreAction) {
         hideDragIndicator();
         if (dropAction == Qt::MoveAction) {
             const ActionList currentActions = m_toolBar->actions();
-            QAction *previous = 0;
+            QAction *previous = nullptr;
             if (index >= 0 && index < currentActions.size())
                 previous = currentActions.at(index);
             InsertActionIntoCommand *cmd = new InsertActionIntoCommand(fw);
@@ -429,7 +421,7 @@ QAction *ToolBarEventFilter::actionAt(const QToolBar *tb, const QPoint &pos)
 {
     const int index = actionIndexAt(tb, pos, tb->orientation());
     if (index == -1)
-        return 0;
+        return nullptr;
     return tb->actions().at(index);
 }
 
@@ -456,7 +448,8 @@ QRect ToolBarEventFilter::freeArea(const QToolBar *tb)
 {
     QRect rc = QRect(QPoint(0, 0), tb->size());
     const ActionList actionList = tb->actions();
-    QRect exclusionRectangle = actionList.empty() ? handleArea(tb) : tb->actionGeometry(actionList.back());
+    QRect exclusionRectangle = actionList.isEmpty()
+        ? handleArea(tb) : tb->actionGeometry(actionList.constLast());
     switch (tb->orientation()) {
     case Qt::Horizontal:
         switch (tb->layoutDirection()) {
