@@ -33,19 +33,19 @@
 
 #include <abstractdialoggui_p.h>
 
-#include <QtDesigner/QDesignerSettingsInterface>
-#include <QtDesigner/QDesignerFormEditorInterface>
+#include <QtDesigner/abstractsettings.h>
+#include <QtDesigner/abstractformeditor.h>
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
-#include <QtCore/QCoreApplication>
-#include <QtXml/QDomDocument>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QHeaderView>
-#include <QtWidgets/QInputDialog>
-#include <QtWidgets/QMessageBox>
-#include <QtWidgets/QPushButton>
-#include <QtGui/QStandardItemModel>
+#include <QtCore/qfileinfo.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qcoreapplication.h>
+#include <QtXml/qdom.h>
+#include <QtWidgets/qmenu.h>
+#include <QtWidgets/qheaderview.h>
+#include <QtWidgets/qinputdialog.h>
+#include <QtWidgets/qmessagebox.h>
+#include <QtWidgets/qpushbutton.h>
+#include <QtGui/qstandarditemmodel.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -75,32 +75,26 @@ namespace {
 struct QtResourceFileData {
     QString path;
     QString alias;
-    bool operator==(const QtResourceFileData &other) const {
-        if (path == other.path && alias == other.alias)
-            return true;
-        return false;
-    }
+    bool operator==(const QtResourceFileData &other) const
+    { return path == other.path && alias == other.alias; }
 };
 
 struct QtResourcePrefixData {
     QString prefix;
     QString language;
     QList<QtResourceFileData> resourceFileList;
-    bool operator==(const QtResourcePrefixData &other) const {
-        if (prefix == other.prefix && language == other.language && resourceFileList == other.resourceFileList)
-            return true;
-        return false;
+    bool operator==(const QtResourcePrefixData &other) const
+    {
+        return prefix == other.prefix && language == other.language
+            && resourceFileList == other.resourceFileList;
     }
 };
 
 struct QtQrcFileData {
     QString qrcPath;
     QList<QtResourcePrefixData> resourceList;
-    bool operator==(const QtQrcFileData &other) const {
-        if (qrcPath == other.qrcPath && resourceList == other.resourceList)
-            return true;
-        return false;
-    }
+    bool operator==(const QtQrcFileData &other) const
+    { return qrcPath == other.qrcPath && resourceList == other.resourceList; }
 };
 
 bool loadResourceFileData(const QDomElement &fileElem, QtResourceFileData *fileData, QString *errorMessage)
@@ -223,7 +217,7 @@ public:
     QString alias() const { return m_alias; }
     QString fullPath() const { return m_fullPath; }
 private:
-    QtResourceFile() {}
+    QtResourceFile() = default;
 
     QString m_path;
     QString m_alias;
@@ -238,7 +232,7 @@ public:
     QString language() const { return m_language; }
     QList<QtResourceFile *> resourceFiles() const { return m_resourceFiles; }
 private:
-    QtResourcePrefix() {}
+    QtResourcePrefix() = default;
 
     QString m_prefix;
     QString m_language;
@@ -256,7 +250,7 @@ public:
     QtQrcFileData initialState() const { return m_initialState; }
 
 private:
-    QtQrcFile() { }
+    QtQrcFile() = default;
 
     void setPath(const QString &path) {
         m_path = path;
@@ -275,8 +269,8 @@ class QtQrcManager : public QObject
 {
     Q_OBJECT
 public:
-    QtQrcManager(QObject *parent = 0);
-    ~QtQrcManager();
+    QtQrcManager(QObject *parent = nullptr);
+    ~QtQrcManager() override;
 
     QList<QtQrcFile *> qrcFiles() const;
 
@@ -285,7 +279,7 @@ public:
     QtQrcFile *qrcFileOf(QtResourcePrefix *resourcePrefix) const;
     QtResourcePrefix *resourcePrefixOf(QtResourceFile *resourceFile) const;
 
-    QtQrcFile *importQrcFile(const QtQrcFileData &qrcFileData, QtQrcFile *beforeQrcFile = 0);
+    QtQrcFile *importQrcFile(const QtQrcFileData &qrcFileData, QtQrcFile *beforeQrcFile = nullptr);
     void exportQrcFile(QtQrcFile *qrcFile, QtQrcFileData *qrcFileData) const;
 
     QIcon icon(const QString &resourceFullPath) const;
@@ -303,20 +297,20 @@ public:
 
 public slots:
 
-    QtQrcFile *insertQrcFile(const QString &path, QtQrcFile *beforeQrcFile = 0, bool newFile = false);
+    QtQrcFile *insertQrcFile(const QString &path, QtQrcFile *beforeQrcFile = nullptr, bool newFile = false);
     void moveQrcFile(QtQrcFile *qrcFile, QtQrcFile *beforeQrcFile);
     void setInitialState(QtQrcFile *qrcFile, const QtQrcFileData &initialState);
     void removeQrcFile(QtQrcFile *qrcFile);
 
     QtResourcePrefix *insertResourcePrefix(QtQrcFile *qrcFile, const QString &prefix,
-                    const QString &language, QtResourcePrefix *beforeResourcePrefix = 0);
+                    const QString &language, QtResourcePrefix *beforeResourcePrefix = nullptr);
     void moveResourcePrefix(QtResourcePrefix *resourcePrefix, QtResourcePrefix *beforeResourcePrefix); // the same qrc file???
     void changeResourcePrefix(QtResourcePrefix *resourcePrefix, const QString &newPrefix);
     void changeResourceLanguage(QtResourcePrefix *resourcePrefix, const QString &newLanguage);
     void removeResourcePrefix(QtResourcePrefix *resourcePrefix);
 
     QtResourceFile *insertResourceFile(QtResourcePrefix *resourcePrefix, const QString &path,
-                    const QString &alias, QtResourceFile *beforeResourceFile = 0);
+                    const QString &alias, QtResourceFile *beforeResourceFile = nullptr);
     void moveResourceFile(QtResourceFile *resourceFile, QtResourceFile *beforeResourceFile); // the same prefix???
     void changeResourceAlias(QtResourceFile *resourceFile, const QString &newAlias);
     void removeResourceFile(QtResourceFile *resourceFile);
@@ -383,11 +377,11 @@ QtQrcFile *QtQrcManager::importQrcFile(const QtQrcFileData &qrcFileData, QtQrcFi
 {
     QtQrcFile *qrcFile = insertQrcFile(qrcFileData.qrcPath, beforeQrcFile);
     if (!qrcFile)
-        return 0;
+        return nullptr;
     for (const QtResourcePrefixData &prefixData : qrcFileData.resourceList) {
-        QtResourcePrefix *resourcePrefix = insertResourcePrefix(qrcFile, prefixData.prefix, prefixData.language, 0);
+        QtResourcePrefix *resourcePrefix = insertResourcePrefix(qrcFile, prefixData.prefix, prefixData.language, nullptr);
         for (const QtResourceFileData &fileData : prefixData.resourceFileList)
-            insertResourceFile(resourcePrefix, fileData.path, fileData.alias, 0);
+            insertResourceFile(resourcePrefix, fileData.path, fileData.alias, nullptr);
     }
     setInitialState(qrcFile, qrcFileData);
     return qrcFile;
@@ -405,10 +399,10 @@ void QtQrcManager::exportQrcFile(QtQrcFile *qrcFile, QtQrcFileData *qrcFileData)
 
     QList<QtResourcePrefixData> resourceList;
 
-    const QList<QtResourcePrefix *> resourcePrefixes = qrcFile->resourcePrefixList();
+    const auto resourcePrefixes = qrcFile->resourcePrefixList();
     for (const QtResourcePrefix *prefix : resourcePrefixes) {
         QList<QtResourceFileData> resourceFileList;
-        const QList<QtResourceFile *> resourceFiles = prefix->resourceFiles();
+        const auto resourceFiles = prefix->resourceFiles();
         for (QtResourceFile *file : resourceFiles) {
             QtResourceFileData fileData;
             fileData.path = file->path();
@@ -445,70 +439,70 @@ bool QtQrcManager::exists(QtQrcFile *qrcFile) const
 QtQrcFile *QtQrcManager::prevQrcFile(QtQrcFile *qrcFile) const
 {
     if (!qrcFile)
-        return 0;
+        return nullptr;
     const int idx = m_qrcFiles.indexOf(qrcFile);
     if (idx <= 0)
-        return 0;
+        return nullptr;
     return m_qrcFiles.at(idx - 1);
 }
 
 QtQrcFile *QtQrcManager::nextQrcFile(QtQrcFile *qrcFile) const
 {
     if (!qrcFile)
-        return 0;
+        return nullptr;
     const int idx = m_qrcFiles.indexOf(qrcFile);
     if (idx < 0 || idx == m_qrcFiles.size() - 1)
-        return 0;
+        return nullptr;
     return m_qrcFiles.at(idx + 1);
 }
 
 QtResourcePrefix *QtQrcManager::prevResourcePrefix(QtResourcePrefix *resourcePrefix) const
 {
     if (!resourcePrefix)
-        return 0;
-    QList<QtResourcePrefix *> prefixes = qrcFileOf(resourcePrefix)->resourcePrefixList();
+        return nullptr;
+    const auto prefixes = qrcFileOf(resourcePrefix)->resourcePrefixList();
     const int idx = prefixes.indexOf(resourcePrefix);
     if (idx <= 0)
-        return 0;
+        return nullptr;
     return prefixes.at(idx - 1);
 }
 
 QtResourcePrefix *QtQrcManager::nextResourcePrefix(QtResourcePrefix *resourcePrefix) const
 {
     if (!resourcePrefix)
-        return 0;
-    QList<QtResourcePrefix *> prefixes = qrcFileOf(resourcePrefix)->resourcePrefixList();
+        return nullptr;
+    const auto prefixes = qrcFileOf(resourcePrefix)->resourcePrefixList();
     const int idx = prefixes.indexOf(resourcePrefix);
     if (idx < 0 || idx == prefixes.size() - 1)
-        return 0;
+        return nullptr;
     return prefixes.at(idx + 1);
 }
 
 QtResourceFile *QtQrcManager::prevResourceFile(QtResourceFile *resourceFile) const
 {
     if (!resourceFile)
-        return 0;
-    QList<QtResourceFile *> files = resourcePrefixOf(resourceFile)->resourceFiles();
+        return nullptr;
+    const auto files = resourcePrefixOf(resourceFile)->resourceFiles();
     const int idx = files.indexOf(resourceFile);
     if (idx <= 0)
-        return 0;
+        return nullptr;
     return files.at(idx - 1);
 }
 
 QtResourceFile *QtQrcManager::nextResourceFile(QtResourceFile *resourceFile) const
 {
     if (!resourceFile)
-        return 0;
-    QList<QtResourceFile *> files = resourcePrefixOf(resourceFile)->resourceFiles();
+        return nullptr;
+    const auto files = resourcePrefixOf(resourceFile)->resourceFiles();
     const int idx = files.indexOf(resourceFile);
     if (idx < 0 || idx == files.size() - 1)
-        return 0;
+        return nullptr;
     return files.at(idx + 1);
 }
 
 void QtQrcManager::clear()
 {
-    const QList<QtQrcFile *> oldQrcFiles = qrcFiles();
+    const auto oldQrcFiles = qrcFiles();
     for (QtQrcFile *qf : oldQrcFiles)
         removeQrcFile(qf);
 }
@@ -516,7 +510,7 @@ void QtQrcManager::clear()
 QtQrcFile *QtQrcManager::insertQrcFile(const QString &path, QtQrcFile *beforeQrcFile, bool newFile)
 {
     if (m_pathToQrc.contains(path))
-        return 0;
+        return nullptr;
 
     int idx = m_qrcFiles.indexOf(beforeQrcFile);
     if (idx < 0)
@@ -551,7 +545,7 @@ void QtQrcManager::moveQrcFile(QtQrcFile *qrcFile, QtQrcFile *beforeQrcFile)
     if (idx == beforeIdx - 1) // the same position, nothing changes
         return;
 
-    QtQrcFile *oldBefore = 0;
+    QtQrcFile *oldBefore = nullptr;
     if (idx < m_qrcFiles.size() - 1)
         oldBefore = m_qrcFiles.at(idx + 1);
 
@@ -575,7 +569,7 @@ void QtQrcManager::removeQrcFile(QtQrcFile *qrcFile)
     if (idx < 0)
         return;
 
-    const QList<QtResourcePrefix *> resourcePrefixes = qrcFile->resourcePrefixList();
+    const auto resourcePrefixes = qrcFile->resourcePrefixList();
     for (QtResourcePrefix *rp : resourcePrefixes)
         removeResourcePrefix(rp);
 
@@ -591,7 +585,7 @@ QtResourcePrefix *QtQrcManager::insertResourcePrefix(QtQrcFile *qrcFile, const Q
         const QString &language, QtResourcePrefix *beforeResourcePrefix)
 {
     if (!qrcFile)
-        return 0;
+        return nullptr;
 
     int idx = qrcFile->m_resourcePrefixes.indexOf(beforeResourcePrefix);
     if (idx < 0)
@@ -629,7 +623,7 @@ void QtQrcManager::moveResourcePrefix(QtResourcePrefix *resourcePrefix, QtResour
     if (idx == beforeIdx - 1) // the same position, nothing changes
         return;
 
-    QtResourcePrefix *oldBefore = 0;
+    QtResourcePrefix *oldBefore = nullptr;
     if (idx < qrcFile->m_resourcePrefixes.size() - 1)
         oldBefore = qrcFile->m_resourcePrefixes.at(idx + 1);
 
@@ -678,7 +672,7 @@ void QtQrcManager::removeResourcePrefix(QtResourcePrefix *resourcePrefix)
 
     const int idx = qrcFile->m_resourcePrefixes.indexOf(resourcePrefix);
 
-    const QList<QtResourceFile *> resourceFiles = resourcePrefix->resourceFiles();
+    const auto resourceFiles = resourcePrefix->resourceFiles();
     for (QtResourceFile *rf : resourceFiles)
         removeResourceFile(rf);
 
@@ -693,7 +687,7 @@ QtResourceFile *QtQrcManager::insertResourceFile(QtResourcePrefix *resourcePrefi
         const QString &alias, QtResourceFile *beforeResourceFile)
 {
     if (!resourcePrefix)
-        return 0;
+        return nullptr;
 
     int idx = resourcePrefix->m_resourceFiles.indexOf(beforeResourceFile);
     if (idx < 0)
@@ -741,7 +735,7 @@ void QtQrcManager::moveResourceFile(QtResourceFile *resourceFile, QtResourceFile
     if (idx == beforeIdx - 1) // the same position, nothing changes
         return;
 
-    QtResourceFile *oldBefore = 0;
+    QtResourceFile *oldBefore = nullptr;
     if (idx < resourcePrefix->m_resourceFiles.size() - 1)
         oldBefore = resourcePrefix->m_resourceFiles.at(idx + 1);
 
@@ -800,7 +794,7 @@ class QtResourceEditorDialogPrivate
     QtResourceEditorDialog *q_ptr;
     Q_DECLARE_PUBLIC(QtResourceEditorDialog)
 public:
-    QtResourceEditorDialogPrivate();
+    QtResourceEditorDialogPrivate() = default;
 
     void slotQrcFileInserted(QtQrcFile *qrcFile);
     void slotQrcFileMoved(QtQrcFile *qrcFile);
@@ -859,10 +853,10 @@ public:
     QString qrcStartDirectory() const;
 
     Ui::QtResourceEditorDialog m_ui;
-    QDesignerFormEditorInterface *m_core;
-    QtResourceModel *m_resourceModel;
-    QDesignerDialogGuiInterface *m_dlgGui;
-    QtQrcManager *m_qrcManager;
+    QDesignerFormEditorInterface *m_core = nullptr;
+    QtResourceModel *m_resourceModel = nullptr;
+    QDesignerDialogGuiInterface *m_dlgGui = nullptr;
+    QtQrcManager *m_qrcManager = nullptr;
     QList<QtQrcFileData> m_initialState;
 
     QMap<QtQrcFile *, QListWidgetItem *> m_qrcFileToItem;
@@ -876,58 +870,30 @@ public:
     QMap<QStandardItem *, QtResourceFile *> m_pathItemToResourceFile;
     QMap<QStandardItem *, QtResourceFile *> m_aliasItemToResourceFile;
 
-    bool m_ignoreCurrentChanged;
-    bool m_firstQrcFileDialog;
-    QtQrcFile *m_currentQrcFile;
+    bool m_ignoreCurrentChanged = false;
+    bool m_firstQrcFileDialog = true;
+    QtQrcFile *m_currentQrcFile = nullptr;
 
-    QAction *m_newQrcFileAction;
-    QAction *m_importQrcFileAction;
-    QAction *m_removeQrcFileAction;
-    QAction *m_moveUpQrcFileAction;
-    QAction *m_moveDownQrcFileAction;
+    QAction *m_newQrcFileAction = nullptr;
+    QAction *m_importQrcFileAction = nullptr;
+    QAction *m_removeQrcFileAction = nullptr;
+    QAction *m_moveUpQrcFileAction = nullptr;
+    QAction *m_moveDownQrcFileAction = nullptr;
 
-    QAction *m_newPrefixAction;
-    QAction *m_addResourceFileAction;
-    QAction *m_changePrefixAction;
-    QAction *m_changeLanguageAction;
-    QAction *m_changeAliasAction;
-    QAction *m_clonePrefixAction;
-    QAction *m_moveUpAction;
-    QAction *m_moveDownAction;
-    QAction *m_removeAction;
+    QAction *m_newPrefixAction = nullptr;
+    QAction *m_addResourceFileAction = nullptr;
+    QAction *m_changePrefixAction = nullptr;
+    QAction *m_changeLanguageAction = nullptr;
+    QAction *m_changeAliasAction = nullptr;
+    QAction *m_clonePrefixAction = nullptr;
+    QAction *m_moveUpAction = nullptr;
+    QAction *m_moveDownAction = nullptr;
+    QAction *m_removeAction = nullptr;
 
-    QStandardItemModel *m_treeModel;
-    QItemSelectionModel *m_treeSelection;
+    QStandardItemModel *m_treeModel = nullptr;
+    QItemSelectionModel *m_treeSelection = nullptr;
 };
 
-QtResourceEditorDialogPrivate::QtResourceEditorDialogPrivate() :
-    q_ptr(0),
-    m_core(0),
-    m_resourceModel(0),
-    m_dlgGui(0),
-    m_qrcManager(0),
-    m_ignoreCurrentChanged(false),
-    m_firstQrcFileDialog(true),
-    m_currentQrcFile(0),
-    m_newQrcFileAction(0),
-    m_importQrcFileAction(0),
-    m_removeQrcFileAction(0),
-    m_moveUpQrcFileAction(0),
-    m_moveDownQrcFileAction(0),
-    m_newPrefixAction(0),
-    m_addResourceFileAction(0),
-    m_changePrefixAction(0),
-    m_changeLanguageAction(0),
-    m_changeAliasAction(0),
-    m_clonePrefixAction(0),
-    m_moveUpAction(0),
-    m_moveDownAction(0),
-    m_removeAction(0),
-    m_treeModel(0),
-    m_treeSelection(0)
-{
-}
-
 QMessageBox::StandardButton QtResourceEditorDialogPrivate::warning(const QString &title, const QString &text, QMessageBox::StandardButtons buttons,
                                                                    QMessageBox::StandardButton defaultButton) const
 {
@@ -995,7 +961,7 @@ void QtResourceEditorDialogPrivate::slotQrcFileRemoved(QtQrcFile *qrcFile)
 {
     QListWidgetItem *item = m_qrcFileToItem.value(qrcFile);
     if (item == m_ui.qrcFileList->currentItem())
-        m_ui.qrcFileList->setCurrentItem(0); // this should trigger list view signal currentItemChanged(0), and slot should set m_currentQrcFile to 0
+        m_ui.qrcFileList->setCurrentItem(nullptr); // this should trigger list view signal currentItemChanged(0), and slot should set m_currentQrcFile to 0
     m_ignoreCurrentChanged = true;
     delete item;
     m_ignoreCurrentChanged = false;
@@ -1006,7 +972,7 @@ void QtResourceEditorDialogPrivate::slotQrcFileRemoved(QtQrcFile *qrcFile)
 QStandardItem *QtResourceEditorDialogPrivate::insertResourcePrefix(QtResourcePrefix *resourcePrefix)
 {
     if (m_qrcManager->qrcFileOf(resourcePrefix) != m_currentQrcFile)
-        return 0;
+        return nullptr;
 
     QtResourcePrefix *prevResourcePrefix = m_qrcManager->prevResourcePrefix(resourcePrefix);
     QStandardItem *prevItem = m_resourcePrefixToPrefixItem.value(prevResourcePrefix);
@@ -1047,7 +1013,7 @@ void QtResourceEditorDialogPrivate::slotResourcePrefixMoved(QtResourcePrefix *re
     const QModelIndex index = m_treeModel->indexFromItem(prefixItem);
     const bool expanded = m_ui.resourceTreeView->isExpanded(index);
     m_ignoreCurrentChanged = true;
-    const QList<QStandardItem *> items = m_treeModel->takeRow(index.row());
+    const auto items = m_treeModel->takeRow(index.row());
 
     int row = m_treeModel->rowCount();
     QtResourcePrefix *nextResourcePrefix = m_qrcManager->nextResourcePrefix(resourcePrefix);
@@ -1160,7 +1126,7 @@ void QtResourceEditorDialogPrivate::slotResourceFileMoved(QtResourceFile *resour
 
     QStandardItem *parentItem = pathItem->parent();
     m_ignoreCurrentChanged = true;
-    const QList<QStandardItem *> items = parentItem->takeRow(m_treeModel->indexFromItem(pathItem).row());
+    const auto items = parentItem->takeRow(m_treeModel->indexFromItem(pathItem).row());
 
     int row = parentItem->rowCount();
     QtResourceFile *nextResourceFile = m_qrcManager->nextResourceFile(resourceFile);
@@ -1223,7 +1189,7 @@ void QtResourceEditorDialogPrivate::slotCurrentQrcFileChanged(QListWidgetItem *i
         QMap<QtResourcePrefix *, QStandardItem *> currentPrefixList = m_resourcePrefixToPrefixItem;
         for (auto it = currentPrefixList.cbegin(), end = currentPrefixList.cend(); it != end; ++it) {
             QtResourcePrefix *resourcePrefix = it.key();
-            const QList<QtResourceFile *> currentResourceFiles = resourcePrefix->resourceFiles();
+            const auto currentResourceFiles = resourcePrefix->resourceFiles();
             for (QtResourceFile *rf : currentResourceFiles)
                 slotResourceFileRemoved(rf);
             slotResourcePrefixRemoved(resourcePrefix);
@@ -1232,14 +1198,14 @@ void QtResourceEditorDialogPrivate::slotCurrentQrcFileChanged(QListWidgetItem *i
 
     m_currentQrcFile = newCurrentQrcFile;
     slotCurrentTreeViewItemChanged(QModelIndex());
-    QStandardItem *firstPrefix = 0; // select first prefix
+    QStandardItem *firstPrefix = nullptr; // select first prefix
     if (m_currentQrcFile) {
-        const QList<QtResourcePrefix *> newPrefixList = m_currentQrcFile->resourcePrefixList();
+        const auto newPrefixList = m_currentQrcFile->resourcePrefixList();
         for (QtResourcePrefix *resourcePrefix : newPrefixList) {
             if (QStandardItem *newPrefixItem = insertResourcePrefix(resourcePrefix))
                 if (!firstPrefix)
                     firstPrefix = newPrefixItem;
-            const QList<QtResourceFile *> newResourceFiles = resourcePrefix->resourceFiles();
+            const auto newResourceFiles = resourcePrefix->resourceFiles();
             for (QtResourceFile *rf : newResourceFiles)
                 slotResourceFileInserted(rf);
         }
@@ -1350,7 +1316,7 @@ QString QtResourceEditorDialogPrivate::getSaveFileNameWithExtension(QWidget *par
 
     QString saveFile;
     while (true) {
-        saveFile = m_dlgGui->getSaveFileName(parent, title, dir, filter, 0, QFileDialog::DontConfirmOverwrite);
+        saveFile = m_dlgGui->getSaveFileName(parent, title, dir, filter, nullptr, QFileDialog::DontConfirmOverwrite);
         if (saveFile.isEmpty())
             return saveFile;
 
@@ -1477,7 +1443,7 @@ QtResourceFile *QtResourceEditorDialogPrivate::getCurrentResourceFile() const
     QStandardItem *currentItem = m_treeModel->itemFromIndex(m_treeSelection->currentIndex());
 
 
-    QtResourceFile *currentResourceFile = 0;
+    QtResourceFile *currentResourceFile = nullptr;
     if (currentItem) {
         currentResourceFile = m_pathItemToResourceFile.value(currentItem);
         if (!currentResourceFile)
@@ -1490,7 +1456,7 @@ QtResourcePrefix *QtResourceEditorDialogPrivate::getCurrentResourcePrefix() cons
 {
     QStandardItem *currentItem = m_treeModel->itemFromIndex(m_treeSelection->currentIndex());
 
-    QtResourcePrefix *currentResourcePrefix = 0;
+    QtResourcePrefix *currentResourcePrefix = nullptr;
     if (currentItem) {
         currentResourcePrefix = m_prefixItemToResourcePrefix.value(currentItem);
         if (!currentResourcePrefix) {
@@ -1576,7 +1542,7 @@ void QtResourceEditorDialogPrivate::slotAddFiles()
 
     QtResourceFile *nextResourceFile = m_qrcManager->nextResourceFile(currentResourceFile);
     if (!currentResourceFile) {
-        QList<QtResourceFile *> resourceFiles = currentResourcePrefix->resourceFiles();
+        const auto resourceFiles = currentResourcePrefix->resourceFiles();
         if (resourceFiles.count() > 0)
             nextResourceFile = resourceFiles.first();
     }
@@ -1694,7 +1660,7 @@ void QtResourceEditorDialogPrivate::slotClonePrefix()
     QtResourcePrefix *newResourcePrefix = m_qrcManager->insertResourcePrefix(m_currentQrcFile, currentResourcePrefix->prefix(),
                                     currentResourcePrefix->language(), m_qrcManager->nextResourcePrefix(currentResourcePrefix));
     if (newResourcePrefix) {
-        const QList<QtResourceFile *> files = currentResourcePrefix->resourceFiles();
+        const auto files = currentResourcePrefix->resourceFiles();
         for (QtResourceFile *resourceFile : files) {
             QString path = resourceFile->path();
             QFileInfo fi(path);
@@ -1723,7 +1689,7 @@ void QtResourceEditorDialogPrivate::slotRemove()
     if (!resourcePrefix)
         resourcePrefix = m_languageItemToResourcePrefix.value(item);
 
-    QStandardItem *newCurrentItem = 0;
+    QStandardItem *newCurrentItem = nullptr;
 
     if (resourceFile) {
         QtResourceFile *nextFile = m_qrcManager->nextResourceFile(resourceFile);
@@ -1794,7 +1760,7 @@ QString QtResourceEditorDialogPrivate::browseForNewLocation(const QString &resou
 {
     QFileInfo fi(resourceFile);
     const QString initialPath = rootDir.absoluteFilePath(fi.fileName());
-    while (1) {
+    while (true) {
         QString newPath = m_dlgGui->getSaveFileName(q_ptr,
                     QCoreApplication::translate("QtResourceEditorDialog", "Copy As"),
                     initialPath);
@@ -1863,7 +1829,10 @@ bool QtResourceEditorDialogPrivate::loadQrcFile(const QString &path, QtQrcFileDa
     QDomDocument doc;
     int errLine, errCol;
     if (!doc.setContent(dataArray, errorMessage, &errLine, &errCol))  {
-        *errorMessage = QCoreApplication::translate("QtResourceEditorDialog", "A parse error occurred at line %1, column %2 of %3:\n%4").arg(errLine).arg(errCol).arg(path).arg(*errorMessage);
+        *errorMessage =
+            QCoreApplication::translate("QtResourceEditorDialog",
+                                        "A parse error occurred at line %1, column %2 of %3:\n%4")
+                                       .arg(errLine).arg(errCol).arg(path, *errorMessage);
         return false;
     }
 
@@ -1875,8 +1844,12 @@ bool QtResourceEditorDialogPrivate::saveQrcFile(const QtQrcFileData &qrcFileData
     QFile file(qrcFileData.qrcPath);
     while (!file.open(QIODevice::WriteOnly)) {
         QMessageBox msgBox(QMessageBox::Warning,
-                QCoreApplication::translate("QtResourceEditorDialog", "Save Resource File"),
-                QCoreApplication::translate("QtResourceEditorDialog", "Could not write %1: %2").arg(qrcFileData.qrcPath).arg(file.errorString()),
+                QCoreApplication::translate("QtResourceEditorDialog",
+                                            "Save Resource File"),
+                QCoreApplication::translate("QtResourceEditorDialog",
+                                            "Could not write %1: %2")
+                                           .arg(qrcFileData.qrcPath,
+                                                file.errorString()),
                 QMessageBox::Cancel|QMessageBox::Ignore|QMessageBox::Retry);
         msgBox.setEscapeButton(QMessageBox::Cancel);
         msgBox.setDefaultButton(QMessageBox::Ignore);
@@ -2095,7 +2068,7 @@ QString QtResourceEditorDialog::selectedResource() const
 
     const QString dotSlash(QStringLiteral("./"));
     const QString dotDotSlash(QStringLiteral("../"));
-    while (1) {
+    while (true) {
         if (resourceEnding.startsWith(slash))
             resourceEnding = resourceEnding.mid(1);
         else if (resourceEnding.startsWith(dotSlash))
@@ -2123,7 +2096,7 @@ void QtResourceEditorDialog::accept()
     QStringList newQrcPaths;
     QList<QtQrcFileData> currentState;
 
-    const QList<QtQrcFile *> qrcFiles = d_ptr->m_qrcManager->qrcFiles();
+    const auto qrcFiles = d_ptr->m_qrcManager->qrcFiles();
     for (QtQrcFile *qrcFile : qrcFiles) {
         QtQrcFileData qrcFileData;
         d_ptr->m_qrcManager->exportQrcFile(qrcFile, &qrcFileData);
